@@ -2,7 +2,7 @@ from py4DSTEM.io.datastructure.py4dstem.calibration import *
 from py4DSTEM.io.datastructure.py4dstem.datacube import *
 from py4DSTEM.io.datastructure.py4dstem.probe import *
 from py4DSTEM.io.datastructure.py4dstem.diffractionslice import *
-from py4DSTEM.io.datastructure.py4dstem.diffractionimage import *
+from py4DSTEM.io.datastructure.py4dstem.virtualdiffraction import *
 from py4DSTEM.io.datastructure.py4dstem.realslice import *
 from py4DSTEM.io.datastructure.py4dstem.virtualimage import *
 from py4DSTEM.io.datastructure.py4dstem.qpoints import *
