@@ -34,7 +34,7 @@ class Calibration(Metadata):
 
     The Calibration object is capable of automatically calling the ``calibrate`` method
     of any other py4DSTEM objects when certain calibrations are updated. The methods
-    that trigger propagation of calibration information are tagged with the 
+    that trigger propagation of calibration information are tagged with the
     @propagating_calibration decorator. Use the ``register_target`` method
     to set up an object to recieve calls to ``calibrate``
 
@@ -163,13 +163,35 @@ class Calibration(Metadata):
     # origin
     def set_qx0(self,x):
         self._params['qx0'] = x
+        x = np.asarray(x)
+        qx0_mean = np.mean(x)
+        qx0_shift = x-qx0_mean
+        self._params['qx0_mean'] = qx0_mean
+        self._params['qx0_shift'] = qx0_shift
+    def set_qx0_mean(self,x):
+        self._params['qx0_mean'] = x
     def get_qx0(self,rx=None,ry=None):
         return self._get_value('qx0',rx,ry)
+    def get_qx0_mean(self):
+        return self._get_value('qx0_mean')
+    def get_qx0shift(self,rx=None,ry=None):
+        return self._get_value('qx0_shift',rx,ry)
 
     def set_qy0(self,x):
         self._params['qy0'] = x
+        x = np.asarray(x)
+        qy0_mean = np.mean(x)
+        qy0_shift = x-qy0_mean
+        self._params['qy0_mean'] = qy0_mean
+        self._params['qy0_shift'] = qy0_shift
+    def set_qy0_mean(self,x):
+        self._params['qy0_mean'] = x
     def get_qy0(self,rx=None,ry=None):
         return self._get_value('qy0',rx,ry)
+    def get_qy0_mean(self):
+        return self._get_value('qy0_mean')
+    def get_qy0shift(self,rx=None,ry=None):
+        return self._get_value('qy0_shift',rx,ry)
 
     def set_qx0_meas(self,x):
         self._params['qx0_meas'] = x
@@ -202,6 +224,17 @@ class Calibration(Metadata):
         if any([x is None for x in ans]):
             ans = None
         return ans
+    def get_origin_mean(self):
+        qx0 = self._get_value('qx0_mean')
+        qy0 = self._get_value('qy0_mean')
+        return qx0,qy0
+    def get_origin_shift(self,rx=None,ry=None):
+        qx0 = self._get_value('qx0_shift',rx,ry)
+        qy0 = self._get_value('qy0_shift',rx,ry)
+        ans = (qx0,qy0)
+        if any([x is None for x in ans]):
+            ans = None
+        return ans
 
     def set_origin_meas(self,x):
         """
@@ -235,8 +268,8 @@ class Calibration(Metadata):
         """
         probe_semiangle, qx0, qy0 = x
         self.set_probe_semiangle(probe_semiangle)
-        self.set_qx0(qx0)
-        self.set_qy0(qy0)
+        self.set_qx0_mean(qx0)
+        self.set_qy0_mean(qy0)
     def get_probe_param(self):
         probe_semiangle = self._get_value('probe_semiangle')
         qx0 = self._get_value('qx0')
@@ -245,7 +278,7 @@ class Calibration(Metadata):
         if any([x is None for x in ans]):
             ans = None
         return ans
-        
+
 
     # ellipse
     def set_a(self,x):
@@ -377,7 +410,7 @@ class Calibration(Metadata):
     def register_target(self,new_target):
         """
         Register an object to recieve calls to it `calibrate`
-        method when certain calibrations get updated 
+        method when certain calibrations get updated
         """
         self._targets.append(new_target)
 
