@@ -8,8 +8,8 @@ try:
     import numba as nb
 except ImportError:
     pass
-from ...utils.tqdmnd import tqdmnd
-from ..datastructure import DataCube
+from py4DSTEM.utils.tqdmnd import tqdmnd
+from py4DSTEM.io.datastructure import DataCube
 
 
 def read_gatan_K2_bin(fp, mem="MEMMAP", binfactor=1, metadata=False, **kwargs):
