@@ -5,18 +5,19 @@ from os.path import exists, splitext
 from typing import Union, Optional
 import h5py
 
-from .native.read import read_py4DSTEM
-from .utils import parse_filetype
+from py4DSTEM.io.native.read import read_py4DSTEM
+from py4DSTEM.io.utils import parse_filetype
 
 
 def read(
     filepath: Union[str,pathlib.Path],
-    root: Optional[str] = '4DSTEM',
+    root: Optional[str] = None,
     tree: Optional[Union[bool,str]] = True,
     **kwargs,
     ):
     """
-    File reader for files written by py4DSTEM.
+    File reader for files written by py4DSTEM. To load non-native
+    file types, use py4DSTEM.import_file.
 
     For files written by py4DSTEM v0.13+, the arguments this function
     accepts and their behaviors are below. For older verions, see
@@ -29,7 +30,11 @@ def read(
         root (str): the path to the root data group in the HDF5 file
             to read from. To examine an HDF5 file written by py4DSTEM
             in order to determine this path, call
-            `py4DSTEM.print_h5_tree(filepath)`.
+            `py4DSTEM.print_h5_tree(filepath)`. If left unspecified,
+            looks in the file and if it finds a single top-level
+            object, loads it. If it finds multiple top-level objects,
+            prints a warning and returns a list of root paths to the
+            top-level object found
         tree (bool or str): indicates what data should be loaded,
             relative to the root group specified above.  must be in
             (`True` or `False` or `noroot`).  If set to `False`, the
@@ -53,7 +58,7 @@ def read(
     assert(exists(filepath)), er2
 
     filetype = parse_filetype(filepath)
-    assert filetype == "py4DSTEM", "Incompatible file type for py4DSTEM.io.read. To import data from a non-py4DSTEM EMD file, use py4DSTEM.io.import_file"
+    assert filetype == "py4DSTEM", "Incompatible file type for py4DSTEM.io.read. To non-native files must be read with py4DSTEM.io.import_file"
 
     # prepare kwargs
     kwargs['root'] = root
