@@ -3,9 +3,9 @@
 import numpy as np
 from scipy.optimize import leastsq
 from typing import Union, Optional
-from ..utils import get_CoM
-from ...utils.tqdmnd import tqdmnd
-from ...io.datastructure import Calibration, PointListArray
+from py4DSTEM.process.utils import get_CoM
+from py4DSTEM.utils.tqdmnd import tqdmnd
+from py4DSTEM.io.datastructure import Calibration, PointListArray
 
 
 def get_Q_pixel_size(q_meas, q_known, units='A'):
