@@ -298,7 +298,6 @@ def find_Bragg_disks_aiml_serial(datacube, probe,
                                  metric = 'mean',
                                  filter_function = None,
                                  name = 'braggpeaks_raw',
-                                 _qt_progress_bar = None,
                                  model_path = None,):
     """
     Finds the Bragg disks in all diffraction patterns of datacube from AI/ML method.
@@ -359,7 +358,6 @@ def find_Bragg_disks_aiml_serial(datacube, probe,
             not need to match the shape of the input diffraction pattern, e.g. the filter
             can be used to bin the diffraction pattern). If using distributed disk
             detection, the function must be able to be pickled with by dill.
-        _qt_progress_bar (QProgressBar instance): used only by the GUI.
         model_path (str): filepath for the model weights (Tensorflow model) to load from.
             By default, if the model_path is not provided, py4DSTEM will search for the
             latest model stored on cloud using metadata json file. It is not recommended to
@@ -455,7 +453,6 @@ def find_Bragg_disks_aiml(datacube, probe,
                           upsample_factor = 16,
                           name = 'braggpeaks_raw',
                           filter_function = None,
-                          _qt_progress_bar = None,
                           model_path = None,
                           distributed = None,
                           CUDA = True,
@@ -518,7 +515,6 @@ def find_Bragg_disks_aiml(datacube, probe,
             not need to match the shape of the input diffraction pattern, e.g. the filter
             can be used to bin the diffraction pattern). If using distributed disk
             detection, the function must be able to be pickled with by dill.
-        _qt_progress_bar (QProgressBar instance): used only by the GUI.
         model_path (str): filepath for the model weights (Tensorflow model) to load from.
             By default, if the model_path is not provided, py4DSTEM will search for the
             latest model stored on cloud using metadata json file. It is not recommended to
