@@ -1,8 +1,8 @@
 import numpy as np
 import matplotlib.pyplot as plt
 from matplotlib.patches import Rectangle
-from .show import show,show_points
-from .overlay import add_grid_overlay
+from py4DSTEM.visualize.show import show,show_points
+from py4DSTEM.visualize.overlay import add_grid_overlay
 
 def show_DP_grid(datacube,x0,y0,xL,yL,axsize=(6,6),returnfig=False,space=0,**kwargs):
     """
